intelmq.bots.collectors.tcp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.tcp package

## Submodules

## intelmq.bots.collectors.tcp.collector module

`intelmq.bots.collectors.tcp.collector.` `BOT`

  alias of `intelmq.bots.collectors.tcp.collector.TCPCollectorBot`

class `intelmq.bots.collectors.tcp.collector.` `TCPCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `connect`()
  `init`()
  `process`()
  `recvall`(conn, n)
  `shutdown`()

## Module contents